trident_chemwidgets.tests package - Trident Chemwidgets - Docs v0.1

Hide navigation sidebar
Hide table of contents sidebar
Back to top
Toggle table of contents sidebar

# trident_chemwidgets.tests package

## Submodules

## trident_chemwidgets.tests.conftest module

class trident_chemwidgets.tests.conftest.MockComm(**kwargs: Any)

  Bases: `Comm`

  A mock Comm object.

  Can be used to inspect calls to Comm’s open/send/close methods.

  close(*args, **kwargs)

    Close the frontend-side version of this comm

  comm_id = 'a-b-c-d'
  kernel = 'Truthy'
  open(*args, **kwargs)

    Open the frontend-side version of this comm

  send(*args, **kwargs)

    Send a message to the frontend-side version of this comm

trident_chemwidgets.tests.conftest.mock_comm()

## trident_chemwidgets.tests.test_nbextension_path module

trident_chemwidgets.tests.test_nbextension_path.test_nbextension_path()

## Module contents